==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/pl.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Ładowanie podglądu…",
    "Saved" : "Zapisano",
    "Admin" : "Admin",
    "a safe home for all your data" : "bezpieczna schowek dla wszystkich twoich danych",
    "Name cannot be empty" : "Nazwa nie może być pusta.",
    "The given name is too long" : "Wpisana nazwa jest zbyt długi",
    "The given web address is too long" : "Wpisany adres internetowy jest zbyt długi",
    "The given legal notice address is too long" : "Podana nota prawna jest zbyt długa",
    "The given privacy policy address is too long" : "Podana polityka prywatności jest zbyt długa",
    "The given slogan is too long" : "Wpisany slogan jest zbyt długi",
    "The given color is invalid" : "Podany kolor jest nieprawidłowy",
    "The file was uploaded" : "Plik został wysłany",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Wgrany plik przekracza wartość upload_max_filesize zdefiniowaną w php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Wysłany plik przekracza wielkość dyrektywy MAX_FILE_SIZE określonej w formularzu HTML",
    "The file was only partially uploaded" : "Załadowany plik został wysłany tylko częściowo.",
    "No file was uploaded" : "Nie wysłano żadnego pliku",
    "Missing a temporary folder" : "Brak folderu tymczasowego",
    "Could not write file to disk" : "Nie można zapisać pliku na dysk",
    "A PHP extension stopped the file upload" : "Rozszerzenie PHP zatrzymało wysyłanie pliku",
    "No file uploaded" : "Nie wysłano pliku",
    "Unsupported image type" : "Nieobsługiwany typ zdjęcia",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Używasz już niestandardowego motywu. Ustawienia aplikacji Theming mogą przez to zostać nadpisane.",
    "Theming" : "Motyw",
    "Legal notice" : "Nota prawna",
    "Privacy policy" : "Polityka prywatności",
    "Adjust the Nextcloud theme" : "Dostosuj motyw Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motywy pozwalają na łatwą personalizację wyglądu Twojej instancji i wspieranych klientów. Efekty będą widoczne dla wszystkich użytkowników.",
    "Name" : "Nazwa",
    "Reset to default" : "Przywróć domyślne",
    "Web link" : "Link",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Kolor",
    "Logo" : "Logo",
    "Upload new logo" : "Wyślij nowe logo",
    "Login image" : "Obraz logowania",
    "Upload new login background" : "Wyślij nowe tło ekranu logowania",
    "Remove background image" : "Usuń obraz tła",
    "Advanced options" : "Opcje zaawansowane",
    "Legal notice link" : "Link noty prawnej",
    "Privacy policy link" : "Link polityki prywatności",
    "Header logo" : "Logo nagłówka",
    "Upload new header logo" : "Wyślij logo nagłówka",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Wyślij nową fav ikonę",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Aby wygenerować favicon oparte o wysłane logo i kolor, zainstaluj rozszerzenie PHP Imagemagick z obsługą SVG.",
    "You are already using a custom theme" : "Używasz już motywu niestandarowego",
    "reset to default" : "przywróć domyślne",
    "Web address" : "adres internetowy",
    "Web address https://…" : "adres internetowy https://…",
    "There is no error, the file uploaded with success" : "Brak błędów, plik wysłano poprawnie.",
    "The uploaded file was only partially uploaded" : "Załadowany plik został wysłany tylko częściowo.",
    "Failed to write file to disk." : "Błąd zapisu na dysk.",
    "A PHP extension stopped the file upload." : "Rozszerzenie PHP zatrzymało wysyłanie pliku."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/pl.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Ładowanie podglądu…",
    "Saved" : "Zapisano",
    "Admin" : "Admin",
    "a safe home for all your data" : "bezpieczna schowek dla wszystkich twoich danych",
    "Name cannot be empty" : "Nazwa nie może być pusta.",
    "The given name is too long" : "Wpisana nazwa jest zbyt długi",
    "The given web address is too long" : "Wpisany adres internetowy jest zbyt długi",
    "The given legal notice address is too long" : "Podana nota prawna jest zbyt długa",
    "The given privacy policy address is too long" : "Podana polityka prywatności jest zbyt długa",
    "The given slogan is too long" : "Wpisany slogan jest zbyt długi",
    "The given color is invalid" : "Podany kolor jest nieprawidłowy",
    "The file was uploaded" : "Plik został wysłany",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Wgrany plik przekracza wartość upload_max_filesize zdefiniowaną w php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Wysłany plik przekracza wielkość dyrektywy MAX_FILE_SIZE określonej w formularzu HTML",
    "The file was only partially uploaded" : "Załadowany plik został wysłany tylko częściowo.",
    "No file was uploaded" : "Nie wysłano żadnego pliku",
    "Missing a temporary folder" : "Brak folderu tymczasowego",
    "Could not write file to disk" : "Nie można zapisać pliku na dysk",
    "A PHP extension stopped the file upload" : "Rozszerzenie PHP zatrzymało wysyłanie pliku",
    "No file uploaded" : "Nie wysłano pliku",
    "Unsupported image type" : "Nieobsługiwany typ zdjęcia",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Używasz już niestandardowego motywu. Ustawienia aplikacji Theming mogą przez to zostać nadpisane.",
    "Theming" : "Motyw",
    "Legal notice" : "Nota prawna",
    "Privacy policy" : "Polityka prywatności",
    "Adjust the Nextcloud theme" : "Dostosuj motyw Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motywy pozwalają na łatwą personalizację wyglądu Twojej instancji i wspieranych klientów. Efekty będą widoczne dla wszystkich użytkowników.",
    "Name" : "Nazwa",
    "Reset to default" : "Przywróć domyślne",
    "Web link" : "Link",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Kolor",
    "Logo" : "Logo",
    "Upload new logo" : "Wyślij nowe logo",
    "Login image" : "Obraz logowania",
    "Upload new login background" : "Wyślij nowe tło ekranu logowania",
    "Remove background image" : "Usuń obraz tła",
    "Advanced options" : "Opcje zaawansowane",
    "Legal notice link" : "Link noty prawnej",
    "Privacy policy link" : "Link polityki prywatności",
    "Header logo" : "Logo nagłówka",
    "Upload new header logo" : "Wyślij logo nagłówka",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Wyślij nową fav ikonę",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Aby wygenerować favicon oparte o wysłane logo i kolor, zainstaluj rozszerzenie PHP Imagemagick z obsługą SVG.",
    "There is no error, the file uploaded with success" : "Brak błędów, plik wysłano poprawnie.",
    "The uploaded file was only partially uploaded" : "Załadowany plik został wysłany tylko częściowo.",
    "Failed to write file to disk." : "Błąd zapisu na dysk.",
    "A PHP extension stopped the file upload." : "Rozszerzenie PHP zatrzymało wysyłanie pliku.",
    "You are already using a custom theme" : "Używasz już motywu niestandarowego",
    "Web address https://…" : "adres internetowy https://…"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
